SystemOrganization addCategory: #'XMLRPC-Client-Tests'!

TestCase subclass: #XMLRPCClientTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'XMLRPC-Client-Tests'!

!XMLRPCClientTests commentStamp: '<historical>' prior: 0!
Unit test framework.!

!XMLRPCClientTests methodsFor: 'asserting' stamp: 'dls 11/12/2002 20:09'!
assertEquals: ob to: other msg: msg 
	"Make sure the two objects are equal."
	ob = other
		ifFalse: [self signalFailure: msg , ' (expected ' , ob asString , ', got ' , other asString , ')']! !

!XMLRPCClientTests methodsFor: 'asserting' stamp: 'dls 11/12/2002 20:09'!
assertNil: ob withMessage: msg 
	"Verify the provided object is nil."
	ob
		ifNotNil: [self signalFailure: msg , ' (expected nil, wasn''t)']! !

!XMLRPCClientTests methodsFor: 'asserting' stamp: 'dls 11/12/2002 20:09'!
assertNotNil: ob withMessage: msg 
	"Verify the provided objects is not nil."
	ob
		ifNil: [self signalFailure: msg , ' (expected not nil, was)']! !

!XMLRPCClientTests methodsFor: 'asserting' stamp: 'dls 11/12/2002 20:09'!
assertSame: ob to: otherOb withMessage: msg 
	"Verify the two objects represent the same instance."
	ob == otherOb
		ifFalse: [self signalFailure: msg , ' (expected ' , ob asString , ', got ' , otherOb asString , ')']! !

XMLRPCClientTests subclass: #XMLRPCDecoderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'XMLRPC-Client-Tests'!

!XMLRPCDecoderTest commentStamp: 'dls 11/12/2002 20:14' prior: 0!
Test the XMLRPC Decoder.

XMLRPCDecoderTest new testDecoder!

!XMLRPCDecoderTest methodsFor: 'instance creation' stamp: 'dls 11/15/2002 01:34'!
suite
	^ (TestSuite named: 'XMLRPCDecoderTests')
		addTest: (XMLRPCDecoderTest selector: #testDecoder)! !

!XMLRPCDecoderTest methodsFor: 'tests' stamp: 'GermanArduino 4/1/2011 20:07'!
testDecoder
	"Test the decoder."
	| e d coll |
	e := XMLRPCEncoder new.
	d := XMLRPCDecoder new.

	coll := OrderedCollection new.
	coll add: 17.
	coll add: 'Some String'.
	coll add: true.
	coll add: false.
	coll add: 3.14159265359.
	coll add: XMLRPCDateTime now.
	coll add: #(1 2 3 'ima g' ).

	coll
		do: [:item | 
			| xdom er dr | 
			er := self
						xmlIfy: (e encode: item).
			xdom := XMLDOMParser parseDocumentFrom: er readStream.
			dr := d
						decode: (xdom elements at: 1).
			"Transcript show: 'Decoded ' , er , ' to ' , dr asString. 
			Transcript cr.]"
			self
				assertEquals: item
				to: dr  
				msg: 'Decoding ' , item className]
			
		! !

!XMLRPCDecoderTest methodsFor: 'tests' stamp: 'GermanArduino 3/29/2011 20:53'!
testDecoderStruct
	"Test the decoder structure."
	| e d dict xdom er dr|
	e := XMLRPCEncoder new.
	d := XMLRPCDecoder new.
	dict := Dictionary new.
	dict at: 'a' put: 'A'.
	dict at: 'b' put: 'B'.

	er := self xmlIfy: (e encodeStruct: dict).


	xdom := XMLDOMParser parseDocumentFrom: er readStream.

	dr := d decodeStruct: (xdom elements at: 1).
			"Transcript show: 'Decoded ' , er , ' to ' , dr asString. 
			Transcript cr."
		self
			assertEquals: dict
				to: dr
				msg: 'Decoding ' , dict className


! !

!XMLRPCDecoderTest methodsFor: 'test support' stamp: 'dls 11/11/2002 23:53'!
xmlIfy: t 
	^ '<?xml version="1.0"?><param>' , t , '</param>'! !

XMLRPCClientTests subclass: #XMLRPCEncoderTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'XMLRPC-Client-Tests'!

!XMLRPCEncoderTest commentStamp: 'dls 11/12/2002 20:14' prior: 0!
Test the XMLRPC Encoder.

XMLRPCEncoderTest new testEncoder!

!XMLRPCEncoderTest methodsFor: 'instance creation' stamp: 'dls 11/15/2002 01:34'!
suite
	^ (TestSuite named: 'XMLRPCEncoderTests')
		addTest: (XMLRPCEncoderTest selector: #testEncoder)! !

!XMLRPCEncoderTest methodsFor: 'tests' stamp: 'GermanArduino 12/12/2010 17:54'!
testEncoder
	"Run all the encoder tests."
	| e d |
	e := XMLRPCEncoder new.
	"Transcript show: 'Running encoder test.'; cr."
	self
		assertEquals: '<value><i4>17</i4></value>'
		to: (e encode: 17)
		msg: 'Encoding int.'.
	self
		assertEquals: '<value><double>3.14159265358979</double></value>'
		to: (e encode: 3.14159265358979)
		msg: 'Encoding float.'.
	self
		assertEquals: '<value><string>pi</string></value>'
		to: (e encode: 'pi')
		msg: 'Encoding string.'.
	self
		assertEquals: '<value><boolean>1</boolean></value>'
		to: (e encode: True)
		msg: 'Encoding True'.
	self
		assertEquals: '<value><boolean>0</boolean></value>'
		to: (e encode: False)
		msg: 'Encoding False'.
	self
		assertEquals: '<value><array><data><value><i4>1</i4></value><value><i4>2</i4></value></data></array></value>'
		to: (e encode: #(1 2 ))
		msg: 'Encoding array.'.
	d := Dictionary new.
	d at: 'b' put: 'B'.
	d at: 'a' put: 'A'.
	self
		assertEquals: '<struct><member><name>b</name><value><string>B</string></value></member><member><name>a</name><value><string>A</string></value></member></struct>'
		to: (e encodeStruct: d)
		msg: 'Encoding struct.'! !

XMLRPCClientTests subclass: #XMLRPCTest
	instanceVariableNames: 'proxy'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'XMLRPC-Client-Tests'!

!XMLRPCTest methodsFor: 'test support' stamp: 'dls 11/15/2002 22:30'!
performCall: method arg: a 
	"Perform method invocation and make sure the result is the same as the  
	passed-in value."
	| r p |
	p := OrderedCollection new.
	p add: a.
	r := proxy invokeMethod: method withArgs: p.
	"Transcript show: 'Invoked ' , method , ' with ' , a asString , ' which returned ' , r asString;
		 cr."
	self
		assertEquals: a
		to: r
		msg: 'Failed on method ' , method.
! !

!XMLRPCTest methodsFor: 'test support' stamp: 'GermanArduino 4/1/2011 20:09'!
performCall: method struct: a 
	"Perform method invocation and make sure the result is the same as the  
	passed-in value."
	| r p |

	r := proxy invokeMethod: method withStruct: a.
	"Transcript show: 'Invoked ' , method , ' with ' , a asString , ' which returned ' , r asString;
		 cr."
	self
		assertEquals: a
		to: r
		msg: 'Failed on method ' , method.
! !

!XMLRPCTest methodsFor: 'running' stamp: 'janniklaval 1/10/2014 04:05'!
setUp
	"Set up the test suite:"
	| url |
	XMLRPCKomServerEchoTest  new setUp. "get the server running on the other end.. make it through groovy/ python if you wish.. Server stop is set in the tearDown"
	url := ZnUrl fromString: 'http://localhost:8081/'.
	proxy := XMLRPCProxy new url: url.
	"Transcript show: 'Set up XMLRPCTest';
		 cr."

	^ self! !

!XMLRPCTest methodsFor: 'instance creation' stamp: 'dls 11/15/2002 02:43'!
suite
	^ (TestSuite named: 'XMLRPCTests')
		addTest: (XMLRPCTest selector: #testInt);
		
		addTest: (XMLRPCTest selector: #testDouble);
		
		addTest: (XMLRPCTest selector: #testString);
		
		addTest: (XMLRPCTest selector: #testBoolean);
		
		addTest: (XMLRPCTest selector: #testArray);
		
		addTest: (XMLRPCTest selector: #testStruct);
		
		addTest: (XMLRPCTest selector: #testDate);

		addTest: (XMLRPCTest selector: #testBinary)! !

!XMLRPCTest methodsFor: 'running' stamp: 'Skrish 9/19/2010 11:35'!
tearDown
	XMLRPCHttpModule stop! !

!XMLRPCTest methodsFor: 'tests' stamp: 'Skrish 9/19/2010 11:31'!
testArray
	"Test arrays."

	self performCall: 'echo.echoArray' arg: #('A' 1 3 2.525)! !

!XMLRPCTest methodsFor: 'tests' stamp: 'SantiagoBragagnolo 9/19/2012 16:02'!
testBinary
	"Test Binary data."
	| r p msg |
	msg := 'Test for base64.'.
	p := OrderedCollection new.
	p add: msg readStream.
	r := proxy invokeMethod: 'echo.echoBinary' withArgs: p.
	
	self assertEquals: msg to: (r contents asString) msg: 'Binary (base64) method failed.'! !

!XMLRPCTest methodsFor: 'tests' stamp: 'dls 11/15/2002 01:35'!
testBoolean
	"Test booleans."
	self performCall: 'echo.echoBoolean' arg: true.
	self performCall: 'echo.echoBoolean' arg: false! !

!XMLRPCTest methodsFor: 'tests' stamp: 'Skrish 9/19/2010 10:54'!
testDateTime
	"Test DateTime."
	self performCall: 'echo.echoDateTime' arg: (XMLRPCDateTime now)! !

!XMLRPCTest methodsFor: 'tests' stamp: 'dls 11/15/2002 00:47'!
testDouble
	"Test doubles."
	self performCall: 'echo.echoDouble' arg: 3.14159265358979! !

!XMLRPCTest methodsFor: 'tests' stamp: 'dls 11/15/2002 00:39'!
testInt
	"Test ints."
	self performCall: 'echo.echoInt' arg: 19.! !

!XMLRPCTest methodsFor: 'tests' stamp: 'Skrish 9/19/2010 10:56'!
testString
	"Test strings."
	self performCall: 'echo.echoString' arg: 'This is a test message.'.
	self performCall: 'echo.echoString' arg: 'Embedded XML see  .'.  "implicit < > tags need to be handled"! !

!XMLRPCTest methodsFor: 'tests' stamp: 'GermanArduino 4/1/2011 20:09'!
testStruct
	"Test structs."
	| d |

	d := Dictionary new.
	d at: 'a' put: 'Value for A'.
	d at: 'b' put: 'Value for B'.

	self performCall: 'echo.echoStruct' struct: d! !

XMLRPCClientTests subclass: #XMLRPCTestFlickr
	instanceVariableNames: 'proxy apiname apikey'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'XMLRPC-Client-Tests'!

!XMLRPCTestFlickr methodsFor: 'running' stamp: 'janniklaval 1/10/2014 04:05'!
setUp
	"This class try to test some xmlrpc methods exposed by Flickr. You need internet connection:"
	| url |
	
	url := ZnUrl fromString: 'http://api.flickr.com/services/xmlrpc/'.

	proxy := XMLRPCProxy new url: url.

	" Flickr key to xmlrpc project. Please use them carefully"

	apiname := 'f325ea24350b657d'.
	apikey := '8ba79f0125a2e9d1f82ebb9cac40d68a'.

	^ self! !

!XMLRPCTestFlickr methodsFor: 'running' stamp: 'GermanArduino 3/26/2011 10:32'!
tearDown
	! !

!XMLRPCTestFlickr methodsFor: 'tests' stamp: 'GermanArduino 3/26/2011 12:38'!
testEchoFlickr
	"Test struct call to Flickrecho service"
	| d r |


	d := Dictionary new.
	d at: 'name' put: apiname.
	d at: 'api_key' put: apikey.

	r := proxy invokeMethod: 'flickr.test.echo' withStruct: d.
	

	"Quick test to check if the returned ByteString contains the same key value and secret passed"
	"Only one of both is needed"
	"self shouldnt: [ r findString: '8ba79f0125a2e9d1f82ebb9cac40d68a' ] raise: 0."
	self shouldnt: [ r findString: 'f325ea24350b657d' ] raise: 0.! !

TestCase subclass: #XMLRPCTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'XMLRPC-Client-Tests'!

!XMLRPCTests commentStamp: 'dls 11/12/2002 20:17' prior: 0!
SUnit tests for all XML-RPC functionality.!

!XMLRPCTests methodsFor: 'instance creation' stamp: 'Skrish 9/19/2010 10:58'!
suite
	| s |
	s := TestSuite named: 'All XML RPC Tests'.
	s
		addTest: (XMLRPCEncoderTest selector: #testEncoder).
	s
		addTest: (XMLRPCDecoderTest selector: #testDecoder).
	s
		addTest: (XMLRPCTest  selector: #testArray).	
	s
		addTest: (XMLRPCTest  selector: #testBinary).	
	s
		addTest: (XMLRPCTest  selector: #testBoolean).	
	s
		addTest: (XMLRPCTest  selector: #testInt).	
	s
		addTest: (XMLRPCTest  selector: #testDateTime).	
	s
		addTest: (XMLRPCTest  selector: #testString).	
	s
		addTest: (XMLRPCTest  selector: #testStruct).	
				
	^ s! !
